@@ -20,16 +20,23 @@ Vue.component('edit-field', {
         example: { }
     },
     data: function () {
-        var fieldType = 'text',
+        var schemaType, fieldType = 'text',
             pattern = this.schema.pattern;
 
+        if ( Array.isArray( this.schema.type ) ) {
+            schemaType = this.schema.type[0];
+        }
+        else {
+            schemaType = this.schema.type;
+        }
+
         if ( this.schema['enum'] ) {
             fieldType = 'select';
         }
-        else if ( this.schema.type == 'boolean' ) {
+        else if ( schemaType == 'boolean' ) {
             fieldType = 'checkbox';
         }
-        else if ( this.schema.type == 'string' ) {
+        else if ( schemaType == 'string' ) {
             if ( this.schema.format == 'textarea' ) {
                 fieldType = 'textarea';
             }
@@ -55,9 +62,9 @@ Vue.component('edit-field', {
                 fieldType = 'markdown';
             }
         }
-        else if ( this.schema.type == 'integer' || this.schema.type == 'number' ) {
+        else if ( schemaType == 'integer' || schemaType == 'number' ) {
             fieldType = 'number';
-            if ( this.schema.type == 'integer' ) {
+            if ( schemaType == 'integer' ) {
                 pattern = this.schema.pattern || '^\\d+$';
             }
         }
@@ -326,7 +333,7 @@ var app = new Vue({
                 }
             }
 
-            if ( this.currentCollection ) {
+            if ( this.currentCollection && this.collections[ this.currentCollection ] ) {
                 this.fetchPage();
             }
             else {
